| shapley.plot | R Documentation |
Visualizes WMSHAP summaries from a shapley object. Features can be selected
using method and method/cutoff, top_n_features,
or explicit features to specify feature selection method.
shapley.plot(
shapley,
plot = "bar",
method = "mean",
cutoff = 0.01,
top_n_features = NULL,
features = NULL,
legendstyle = "continuous",
scale_colour_gradient = NULL,
labels = NULL
)
shapley |
object of class |
plot |
Character. One of |
method |
Character. One of |
cutoff |
Numeric cutoff for |
top_n_features |
Integer. If set, selects top N features by WMSHAP (overrides cutoff and method arguments). |
features |
Character vector, specifying the feature to be plotted (overrides cutoff and method arguments). |
legendstyle |
Character. For |
scale_colour_gradient |
Optional character vector of length 3, specifying
color names: |
labels |
Optional named character vector mapping feature names to display labels.
To specify the labels, use the |
A ggplot object
E. F. Haghish
## Not run:
# load the required libraries for building the base-learners and the ensemble models
library(h2o) #shapley supports h2o models
library(shapley)
# initiate the h2o server
h2o.init(ignore_config = TRUE, nthreads = 2, bind_to_localhost = FALSE, insecure = TRUE)
# upload data to h2o cloud
prostate_path <- system.file("extdata", "prostate.csv", package = "h2o")
prostate <- h2o.importFile(path = prostate_path, header = TRUE)
### H2O provides 2 types of grid search for tuning the models, which are
### AutoML and Grid. Below, I demonstrate how weighted mean shapley values
### can be computed for both types.
set.seed(10)
#######################################################
### PREPARE AutoML Grid (takes a couple of minutes)
#######################################################
# run AutoML to tune various models (GBM) for 60 seconds
y <- "CAPSULE"
prostate[,y] <- as.factor(prostate[,y]) #convert to factor for classification
aml <- h2o.automl(y = y, training_frame = prostate, max_runtime_secs = 120,
include_algos=c("GBM"),
# this setting ensures the models are comparable for building a meta learner
seed = 2023, nfolds = 10,
keep_cross_validation_predictions = TRUE)
### call 'shapley' function to compute the weighted mean and weighted confidence intervals
### of SHAP values across all trained models.
### Note that the 'newdata' should be the testing dataset!
result <- shapley(models = aml, newdata = prostate, plot = TRUE)
#######################################################
### PLOT THE WEIGHTED MEAN SHAP VALUES
#######################################################
shapley.plot(result, plot = "bar")
shapley.plot(result, plot = "wmshap")
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.